@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,7 +12,7 @@ package Kernel::System::ACL::DB::ACL;
 use strict;
 use warnings;
 
-use Kernel::Language qw(Translatable);
+use Kernel::Language              qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 our @ObjectDependencies = (
@@ -69,7 +69,7 @@ add new ACL
 returns the id of the created ACL if success or undef otherwise
 
     my $ID = $ACL->ACLAdd(
-        Name           => 'NameOfACL'           # mandatory
+        Name           => 'NameOfACL',          # mandatory
         Comment        => 'Comment',            # optional
         Description    => 'Description',        # optional
         StopAfterMatch => 1,                    # optional
@@ -169,8 +169,8 @@ sub ACLAdd {
                 config_change, valid_id, create_time, create_by, change_time, change_by )
             VALUES (?, ?, ?, ?, ?, ?, ?, current_timestamp, ?, current_timestamp, ?)',
         Bind => [
-            \$Param{Name}, \$Param{Comment}, \$Param{Description}, \$Param{StopAfterMatch},
-            \$ConfigMatch, \$ConfigChange, \$Param{ValidID},
+            \$Param{Name},   \$Param{Comment}, \$Param{Description}, \$Param{StopAfterMatch},
+            \$ConfigMatch,   \$ConfigChange,   \$Param{ValidID},
             \$Param{UserID}, \$Param{UserID},
         ],
     );
@@ -549,9 +549,9 @@ sub ACLUpdate {
                 config_match = ?, config_change = ?, change_time = current_timestamp,  change_by = ?
             WHERE id = ?',
         Bind => [
-            \$Param{Name}, \$Param{Comment}, \$Param{Description}, \$Param{StopAfterMatch},
-            \$Param{ValidID}, \$ConfigMatch, \$ConfigChange,
-            \$Param{UserID}, \$Param{ID},
+            \$Param{Name},    \$Param{Comment}, \$Param{Description}, \$Param{StopAfterMatch},
+            \$Param{ValidID}, \$ConfigMatch,    \$ConfigChange,
+            \$Param{UserID},  \$Param{ID},
         ],
     );
 
@@ -817,12 +817,13 @@ gets a complete ACL information dump from the DB
 
     my $ACLDump = $ACLObject->ACLDump(
         ResultType  => 'SCALAR'                     # 'SCALAR' || 'HASH' || 'FILE'
-        Location    => '/opt/otrs/var/myfile.txt'   # mandatory for ResultType = 'FILE'
+        Location    => '/opt/znuny/var/myfile.txt'   # mandatory for ResultType = 'FILE'
         UserID      => 1,
     );
 
 Returns:
-    $ACLDump = '/opt/otrs/var/myfile.txt';          # or undef if can't write the file
+
+    $ACLDump = '/opt/znuny/var/myfile.txt';          # or undef if can't write the file
 
 =cut
 
@@ -881,6 +882,18 @@ sub ACLDump {
             $PossibleNot = $ACLData->{ConfigChange}->{PossibleNot};
         }
 
+        # Remove line breaks and quotation marks from name so that
+        # it can be safely used as hash key name in generated ACL Perl file.
+        $ACLData->{Name} =~ s{[\r\n\\'"]}{}smg;
+
+        # Remove any line breaks from comment and user name so that following lines
+        # won't be evaluated as Perl.
+        FIELDNAME:
+        for my $FieldName (qw(CreateBy ChangeBy Comment)) {
+            next FIELDNAME if !IsStringWithData( $ACLData->{$FieldName} );
+            $ACLData->{$FieldName} =~ s{[\r\n]}{}smg;
+        }
+
         $ACLDump{ $ACLData->{Name} } = {
             CreateTime => $ACLData->{CreateTime},
             ChangeTime => $ACLData->{ChangeTime},
@@ -909,12 +922,12 @@ sub ACLDump {
         # create output
         $Output .= $Self->_ACLItemOutput(
             Key        => $ACLName,
-            Value      => $ACLDump{$ACLName}{Values},
-            Comment    => $ACLDump{$ACLName}{Comment},
-            CreateTime => $ACLDump{$ACLName}{CreateTime},
-            ChangeTime => $ACLDump{$ACLName}{ChangeTime},
-            CreateBy   => $ACLDump{$ACLName}{CreateBy},
-            ChangeBy   => $ACLDump{$ACLName}{ChangeBy},
+            Value      => $ACLDump{$ACLName}->{Values},
+            Comment    => $ACLDump{$ACLName}->{Comment},
+            CreateTime => $ACLDump{$ACLName}->{CreateTime},
+            ChangeTime => $ACLDump{$ACLName}->{ChangeTime},
+            CreateBy   => $ACLDump{$ACLName}->{CreateBy},
+            ChangeBy   => $ACLDump{$ACLName}->{ChangeBy},
         );
     }
 
@@ -1033,11 +1046,11 @@ sub ACLImport {
                 %{ $ExistingACLs[0] },
                 Name           => $ACL->{Name},
                 Comment        => $ACL->{Comment},
-                Description    => $ACL->{Description} || '',
+                Description    => $ACL->{Description}    || '',
                 StopAfterMatch => $ACL->{StopAfterMatch} || 0,
-                ConfigMatch    => $ACL->{ConfigMatch} || undef,
-                ConfigChange   => $ACL->{ConfigChange} || undef,
-                ValidID        => $ACL->{ValidID} || 1,
+                ConfigMatch    => $ACL->{ConfigMatch}    || undef,
+                ConfigChange   => $ACL->{ConfigChange}   || undef,
+                ValidID        => $ACL->{ValidID}        || 1,
                 UserID         => $Param{UserID},
             );
 
@@ -1055,8 +1068,8 @@ sub ACLImport {
             my $Success = $Self->ACLAdd(
                 Name           => $ACL->{Name},
                 Comment        => $ACL->{Comment},
-                Description    => $ACL->{Description} || '',
-                ConfigMatch    => $ACL->{ConfigMatch} || undef,
+                Description    => $ACL->{Description}  || '',
+                ConfigMatch    => $ACL->{ConfigMatch}  || undef,
                 ConfigChange   => $ACL->{ConfigChange} || undef,
                 StopAfterMatch => $ACL->{StopAfterMatch},
                 ValidID        => $ACL->{ValidID} || 1,
@@ -1074,9 +1087,9 @@ sub ACLImport {
 
     return {
         Success     => 1,
-        AddedACLs   => join( ', ', @AddedACLs ) || '',
+        AddedACLs   => join( ', ', @AddedACLs )   || '',
         UpdatedACLs => join( ', ', @UpdatedACLs ) || '',
-        ACLErrors   => join( ', ', @ACLErrors ) || '',
+        ACLErrors   => join( ', ', @ACLErrors )   || '',
     };
 }
 
