@@ -1547,11 +1547,11 @@ sub CheckNumberOfEventExecution {
 This function calls a list of other helper functions to setup a test environment with various test data.
 
     my $Result = $HelperObject->SetupTestEnvironment(
-        ... # Parameters get passed to the FillTestEnvironment and ConfigureViews function
+        # ... # Parameters get passed to the FillTestEnvironment and ConfigureViews function
     );
 
     $Result = {
-        ... # Combined result of the ActivateDefaultDynamicFields, FillTestEnvironment and ConfigureViews functions
+        # ... # Combined result of the ActivateDefaultDynamicFields, FillTestEnvironment and ConfigureViews functions
     }
 
 =cut
@@ -1657,7 +1657,7 @@ Toggles settings for a given view like AgentTicketNote or CustomerTicketMessage.
             TicketType       => 1,
             Title            => 1,
             HistoryType      => 'Phone',
-            ...
+            # ...
         },
         CustomerTicketMessage => {
             Priority         => 1,
@@ -1668,7 +1668,7 @@ Toggles settings for a given view like AgentTicketNote or CustomerTicketMessage.
             SLAMandatory     => 1,
             TicketType       => 1,
             ArticleType      => 'note-external',
-            ...
+            # ...
         },
     }
 
@@ -2061,7 +2061,7 @@ Default parameters contain various special chars.
     my $Result = $HelperObject->FillTestEnvironment(
         Type => {
             'Type 1::Sub Type' => 1,
-            ...
+            # ...
         }
     );
 
@@ -2150,10 +2150,10 @@ sub FillTestEnvironment {
     my %AttributeTestStructure = (
         'A::Level - 1::A'  => 0,
         'A::Level - 1::B'  => 0,
-        'A::Level - 2::Ä' => 0,
-        'A::Level - 2::Ö' => 0,
-        'B::Level - !::Ü' => 0,
-        'B::Level - !::ß' => 0,
+        'A::Level - 2::Ä'  => 0,
+        'A::Level - 2::Ö'  => 0,
+        'B::Level - !::Ü'  => 0,
+        'B::Level - !::ß'  => 0,
         'B::Level - ?::Y'  => 0,
         'B::Level - ?::Z'  => 0,
         'C::Level - &::%'  => 0,
@@ -2341,13 +2341,14 @@ Creates a Ticket with dummy data and tests the creation. All Ticket attributes a
         UserID       => 1,
     );
 
-    To overwrite:
+To overwrite:
 
     my $TicketID = $HelperObject->TicketCreate(
         CustomerUser => 'another_customer@example.com',
     );
 
-    Result:
+Result:
+
     $TicketID = 1337;
 
 =cut
@@ -2419,14 +2420,15 @@ Creates an Article with dummy data and tests the creation. All Article attribute
         NoAgentNotify  => 1,
     );
 
-    To overwrite:
+To overwrite:
 
     my $ArticleID = $HelperObject->ArticleCreate(
         TicketID   => 1337,
         SenderType => 'customer',
     );
 
-    Result:
+Result:
+
     $ArticleID = 1337;
 
 =cut
